@@ -1,17 +1,8 @@
-#
-# This file is part of Metabase
-#
-# This software is Copyright (c) 2010 by David Golden.
-#
-# This is free software, licensed under:
-#
-#   The Apache License, Version 2.0, January 2004
-#
 package Test::Metabase::Gateway;
 
 use Moose;
 use MooseX::Types::Path::Class qw/Dir/;
-use Metabase::Archive::SQLite;
+use Metabase::Archive::Filesystem;
 use Metabase::Index::FlatFile;
 use Metabase::Librarian;
 use namespace::autoclean;
@@ -41,7 +32,7 @@ sub _build__gateway_storage {
   
 sub _build_public_librarian {
   my $self = shift;
-  my $archive_store = $self->_gateway_storage->file('public.sqlite');
+  my $archive_store = $self->_gateway_storage->dir('public.archive');
   my $index_store = $self->_gateway_storage->file('public.index');
   $index_store->touch;
   return $self->__build_librarian($archive_store, $index_store);
@@ -49,7 +40,7 @@ sub _build_public_librarian {
 
 sub _build_private_librarian {
   my $self = shift;
-  my $archive_store = $self->_gateway_storage->file('private.sqlite');
+  my $archive_store = $self->_gateway_storage->dir('private.archive');
   my $index_store = $self->_gateway_storage->file('private.index');
   $index_store->touch;
   return $self->__build_librarian($archive_store, $index_store);
@@ -58,8 +49,8 @@ sub _build_private_librarian {
 sub __build_librarian {
   my $self = shift;
   return Metabase::Librarian->new(
-    archive => Metabase::Archive::SQLite->new(
-      filename => $_[0]->stringify, compressed => 0
+    archive => Metabase::Archive::Filesystem->new(
+      root_dir => $_[0]->stringify
     ),
     index => Metabase::Index::FlatFile->new(
       index_file => $_[1]->stringify
